@@ -83,13 +83,13 @@ MainWindow *MainWindow::present_default(const Note::Ptr & note)
   if(win) {
     return win;
   }
-  if(false == Preferences::obj().get_schema_settings(Preferences::SCHEMA_GNOTE)->get_boolean(
-                Preferences::OPEN_NOTES_IN_NEW_WINDOW)) {
+  Glib::RefPtr<Gio::Settings> settings = Preferences::obj().get_schema_settings(Preferences::SCHEMA_GNOTE);
+  if(false == settings->get_boolean(Preferences::OPEN_NOTES_IN_NEW_WINDOW)) {
     win = dynamic_cast<MainWindow*>(note->get_window()->host());
   }
   if(!win) {
     win = &IGnote::obj().new_main_window();
-    win->close_on_escape(true);
+    win->close_on_escape(settings->get_boolean(Preferences::ENABLE_CLOSE_NOTE_ON_ESCAPE));
   }
   win->present_note(note);
   win->present();
